@@ -22,6 +22,7 @@ from unstructured.ingest.connector.google_drive import (
     GoogleDriveConnector,
     SimpleGoogleDriveConfig,
 )
+from unstructured.ingest.connector.local import LocalConnector, SimpleLocalConfig
 from unstructured.ingest.connector.reddit import RedditConnector, SimpleRedditConfig
 from unstructured.ingest.connector.s3 import S3Connector, SimpleS3Config
 from unstructured.ingest.connector.wikipedia import (
@@ -43,6 +44,7 @@ class MainProcess:
         num_processes,
         reprocess,
         verbose,
+        max_docs,
     ):
         # initialize the reader and writer
         self.doc_connector = doc_connector
@@ -50,6 +52,7 @@ class MainProcess:
         self.num_processes = num_processes
         self.reprocess = reprocess
         self.verbose = verbose
+        self.max_docs = max_docs
 
     def initialize(self):
         """Slower initialization things: check connections, load things into memory, etc."""
@@ -63,6 +66,10 @@ class MainProcess:
     def _filter_docs_with_outputs(self, docs):
         num_docs_all = len(docs)
         docs = [doc for doc in docs if not doc.has_output()]
+        if self.max_docs is not None:
+            if num_docs_all > self.max_docs:
+                num_docs_all = self.max_docs
+            docs = docs[: self.max_docs]
         num_docs_to_process = len(docs)
         if num_docs_to_process == 0:
             logger.info(
@@ -103,6 +110,12 @@ class MainProcess:
 
 
 @click.command()
+@click.option(
+    "--max-docs",
+    default=None,
+    type=int,
+    help="If specified, process at most specified number of documents.",
+)
 @click.option(
     "--flatten-metadata",
     is_flag=True,
@@ -131,6 +144,23 @@ class MainProcess:
     "Usage: provide a single string with comma separated values. "
     "Example: --metadata-exclude filename,page_number ",
 )
+@click.option(
+    "--local-input-path",
+    default=None,
+    help="Path to the location in the local file system that will be processed.",
+)
+@click.option(
+    "--local-recursive",
+    is_flag=True,
+    default=False,
+    help="Support recursive local file processing.",
+)
+@click.option(
+    "--local-file-glob",
+    default=None,
+    help="A comma-separated list of file globs to limit which types of local files are accepted,"
+    " e.g. '*.html,*.txt'",
+)
 @click.option(
     "--remote-url",
     default=None,
@@ -354,6 +384,10 @@ def main(
     metadata_exclude,
     fields_include,
     flatten_metadata,
+    max_docs,
+    local_input_path,
+    local_recursive,
+    local_file_glob,
 ):
     if flatten_metadata and "metadata" not in fields_include:
         logger.warning(
@@ -375,7 +409,7 @@ def main(
         logger.warning(
             "Not preserving downloaded files but --download_dir is specified",
         )
-    if not download_dir:
+    if local_input_path is None and not download_dir:
         cache_path = Path.home() / ".cache" / "unstructured" / "ingest"
         if not cache_path.exists():
             cache_path.mkdir(parents=True, exist_ok=True)
@@ -597,6 +631,19 @@ def main(
                 flatten_metadata=flatten_metadata,
             ),
         )
+    elif local_input_path:
+        doc_connector = LocalConnector(  # type: ignore
+            config=SimpleLocalConfig(
+                input_path=local_input_path,
+                recursive=local_recursive,
+                file_glob=local_file_glob,
+                # defaults params:
+                output_dir=structured_output_dir,
+                metadata_include=metadata_include,
+                metadata_exclude=metadata_exclude,
+                fields_include=fields_include,
+            ),
+        )
     # Check for other connector-specific options here and define the doc_connector object
     # e.g. "elif azure_container:  ..."
 
@@ -610,6 +657,7 @@ def main(
         num_processes=num_processes,
         reprocess=reprocess,
         verbose=verbose,
+        max_docs=max_docs,
     ).run()
 
 
